/*
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#include"statdialog.h"
#include<vector>
#include<libintl.h>
#include"mainwindow.h"

StatDialog::StatDialog(BaseObjectType* cobject, 
                       const Glib::RefPtr<Gnome::Glade::Xml>& refGlade)
: Gtk::Window(cobject),
  m_refGlade(refGlade),
  periodsCountLabel(0),
  avLengthLabel(0),
  minLengthLabel(0),
  maxLengthLabel(0),
  calendarAccuracyLabel(0)
{
    refGlade->get_widget("PeriodsCountLabel", periodsCountLabel);
    refGlade->get_widget("AvLengthLabel", avLengthLabel);
    refGlade->get_widget("MinLengthLabel", minLengthLabel);
    refGlade->get_widget("MaxLengthLabel", maxLengthLabel);
    refGlade->get_widget("CalendarAccuracyLabel", calendarAccuracyLabel);
    
    Gtk::Button* pButton = 0;
    // connect the signal handlers
    refGlade->get_widget("OKButton", pButton);
    if(pButton)
    {
      pButton->signal_clicked().connect(sigc::mem_fun(*this, &StatDialog::on_ok_click));
    }
    
    // initiate the graph widget
    Gtk::Frame * gframe;
    refGlade->get_widget("GraphFrame", gframe);
    if(gframe) {
        gm = new TGraphModel();
        gw = manage(new TGraphWidget(gm));
        gframe->add(*gw);
    }
    show_all_children();
}


StatDialog::~StatDialog()
{
    delete gm; // need to release the model manually
}

void StatDialog::on_ok_click() 
{
	hide();
}

void StatDialog::present(PCalMainWindow * main_window)
{    
    Glib::ustring tmpstr;
    char tmpchars[10];

    snprintf(tmpchars,10,"%u",main_window->engine->periodsCount);
    tmpstr.assign(tmpchars);
    periodsCountLabel->set_text(tmpstr);

    snprintf(tmpchars,10,"%u",main_window->engine->avgLength);
    tmpstr.assign(tmpchars);
    avLengthLabel->set_text(tmpstr);

    snprintf(tmpchars,10,"%u",main_window->engine->minLength);
    tmpstr.assign(tmpchars);
    minLengthLabel->set_text(tmpstr);

    snprintf(tmpchars,10,"%u",main_window->engine->maxLength);
    tmpstr.assign(tmpchars);
    maxLengthLabel->set_text(tmpstr);

    switch(main_window->engine->calMethodAccuracy) {
        case 0: tmpstr = gettext("High"); break;
        case 1: tmpstr = gettext("Medium"); break;
        case 2: tmpstr = gettext("Low"); break;
        default: tmpstr = gettext("No Data");
    }
    calendarAccuracyLabel->set_text(tmpstr);

    // pass the data to the model
    TGraphSeries series;
    TGraphPoint tmp_point;
    // get the statistics from the engine
    std::vector<PCalPeriodInfo> pstats = 
               main_window->engine->getPeriodsStats();
    for(unsigned i=0; i< pstats.size(); i++) {
        // tmp_point.x = pstats[i].endDate;
        tmp_point.x = i + 1;
        tmp_point.y = pstats[i].length;
        series.points.push_back(tmp_point);
    }

    // add the series to the model
    gm->series.push_back(series);
    gw->set_auto_scale_x(true);
    gw->set_auto_scale_y(true);
    gw->set_grid_x_step(1);
    gw->set_grid_y_step(1);
    gw->set_axe_x_step(1);
    gw->set_axe_y_step(1);
    gw->set_axe_x_label_format("%.0f");
    gw->set_axe_y_label_format("%.0f");

    Gtk::Window::present();
}
